<?php
/**
 * Skrill Payment
 *
 * The Class for Process Skrill Payment Gateways
 * Copyright (c) Skrill
 *
 * @class   SkrillPayment
 * @package Skrill/Classes
 * @located at /controllers
 */
class SkrillPayment extends SkrillPayment_parent
{
    /**
     * Check payment list for billpay availability
     * overwrite
     *
     * @return object
     */
    public function getPaymentList()
    {
        $paymentList = parent::getPaymentList();

        if (oxRegistry::getSession()->getUser()->oxuser__oxpassword->value != '') {
            $userLogin = true;
        }

        $userCountryCode = SkrillOxCountry::getUserCountryIso3();

        foreach ($paymentList as $key => $value) {
            if (strpos($key, 'skrill') !== false) {
                $paymentConfig = SkrillConfig::getPaymentConfig($key);

                // Don't show payment method if the country of user is not allowed for the payment method
                if (! self::isCountryAllowed($userCountryCode, $paymentConfig)) {
                    unset($paymentList[$key]);
                    continue;
                }

                $paymentList[$key]->oxpayments__oxdesc->skrill = true;

                $paymentList[$key]->oxpayments__oxdesc->value =
                    SkrillCore::getFrontendLogoHtmlById($key, $userCountryCode);
            }
        }

        return $paymentList;
    }

    /**
     * @param  string country code 3 characters
     * @param  array filled with payment config
     * @return boolean
     */
    private function isCountryAllowed($countryCode, $config)
    {
        $allowedCountries = $config['allowed_countries'];
        $exceptedCountries = $config['excepted_countries'];

        // if all countries is allowed
        if (!is_array($allowedCountries) && strtoupper($allowedCountries) == 'ALL') {
            // if no country exception
            if (!$exceptedCountries || count($exceptedCountries) == 0) {
                return true;
            }

            // if there's country exception
            if (( $exceptedCountries && count($exceptedCountries) > 0 ) && in_array($countryCode, $exceptedCountries)) {
                return false;
            }
        }

        // if not all country allowed
        if (is_array($allowedCountries) && count($allowedCountries) > 0) {
            if ($config['brand'] == 'AOB' || $config['brand'] == 'ADB' || $config['brand'] == 'ACI') {
                $isAllowed = in_array($countryCode, array_keys($allowedCountries));
            } else {
                $isAllowed = in_array($countryCode, $allowedCountries);
            }

            if (!$isAllowed) {
                return false;
            }
        }

        return true;
    }
}
