<?php
/**
* 2015 Skrill
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
*
*  @author    Skrill <contact@skrill.com>
*  @copyright 2015 Skrill
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of Skrill
*/

class SkrillPaymentAbstract extends oxUBase
{

    protected $_sThisTemplate = 'SkrillPaymentIframe.tpl';
    protected $cartItems = false;
    protected $_blIsOrderStep = true;

    protected $paymentMethod = '';
    protected $subPaymentMethod = '';

    public function render()
    {
        if (!empty(oxRegistry::getSession()->getVariable('skrill_order_status'))) {
            oxRegistry::getSession()->deleteVariable('skrill_order_status');
            oxRegistry::getUtils()->redirect(oxRegistry::getConfig()->getSslShopUrl(), false);
        }
        
        // do when user reload payment widget after make payment
        $oxid = oxRegistry::getSession()->getVariable('sess_challenge');
        if (empty($oxid) && empty(oxRegistry::getSession()->getVariable('skrill_order_status'))) {
            oxRegistry::getUtils()->redirect(oxRegistry::getConfig()->getSslShopUrl(), false);
        }
        if (!empty($oxid)) {
            $order = SkrillCore::getOrderById($oxid);
            $status = $order->oxorder__skrill__status->value;
            if (!empty($status)) {
                SkrillLogger::set()->info('Skrill - user reload payment widget with status: ' . $status);
                $transactionId = $order->oxorder__skrill__transaction_id->value;
                $returnUrl = $this->getReturnUrl($oxid) . '&transaction_id=' . $transactionId;
                SkrillLogger::set()->info('Skrill - redirect to return url: ' . $returnUrl);
                oxRegistry::getUtils()->redirect($returnUrl, false);
            }
        }
        // end do

        oxRegistry::getConfig()->setConfigParam('skrill__prevent_recalculate', true);
        oxRegistry::getSession()->getBasket()->afterUpdate();
        parent::render();

        $postParameters = $this->getPostParameters();
        SkrillLogger::set()->info('Skrill - post parameters : '.json_encode($postParameters));

        $this->updateOrderTransactionId($postParameters['transaction_id']);

        $sid = oxRegistry::getSession()->getVariable('skrill_sid');
        if (empty($sid)) {
            try {
                $sid = SkrillCore::getSid($postParameters);
            } catch (Exception $e) {
                SkrillLogger::set()->info('Skrill - error when generate sid '. $e->getMessage());
                $this->redirectError('ERROR_GENERAL_REDIRECT');
            }
            oxRegistry::getSession()->setVariable('skrill_sid', $sid);
        }
        $redirectUrl = SkrillCore::getSkrillRedirectUrl($sid);

        oxRegistry::getUtils()->redirect($redirectUrl);

        $this->_aViewData['redirectUrl'] = $redirectUrl;

        return $this->_sThisTemplate;
    }

    /**
     * Redirect when error payment process
     *
     * @param  string $errorIdentifier error identifier
     */
    private function redirectError($errorIdentifier)
    {
        oxRegistry::get('oxUtilsView')->addErrorToDisplay($errorIdentifier);
        $redirectUrl = oxRegistry::getConfig()->getSslShopUrl() . 'index.php?cl=order';
        oxRegistry::getUtils()->redirect($redirectUrl);
    }

    private function getPostParameters()
    {
        $order = SkrillOxOrder::refreshOrder();
        $basket = oxRegistry::getSession()->getBasket();
        $user = oxRegistry::getSession()->getUser();
        $orderNumber = $order->oxorder__oxordernr->value;
        $oxid = $order->oxorder__oxid->value;

        $dateTime = SkrillCore::getDateTime();
        $randomNumber = SkrillCore::randomNumber(4);
        $skrillSettings = $this->getSkrillSettings();

        if (empty($skrillSettings['merchant_id'])
            || empty($skrillSettings['merchant_account'])
            || empty($skrillSettings['recipient_desc'])
            || empty($skrillSettings['api_passwd'])
            || empty($skrillSettings['secret_word'])) {
            $messageLog = 'Skrill - general setting is not completed. either of the parameter is not filled';
            SkrillLogger::set()->info($messageLog);
            $this->redirectError('ERROR_GENERAL_REDIRECT');
        }

        if ($this->paymentMethod == 'IDL') {
            $firstname = $order->oxorder__oxbillfname->value;
            $lastname = $order->oxorder__oxbilllname->value;

            if (empty($firstname) || empty($lastname)) {
                $messageLog = 'Skrill iDEAL - firstname, lastname is required';
                SkrillLogger::set()->info($messageLog);
                $this->redirectError('ERROR_CUSTOMER_NAME_REQUIRED');
            }
        }

        $postParameters = array();
        $postParameters['pay_to_email'] = $skrillSettings['merchant_account'];
        $postParameters['recipient_description'] = $skrillSettings['recipient_desc'];
        $postParameters['transaction_id'] = $orderNumber . $dateTime;
        $postParameters['return_url'] = $this->getReturnUrl($oxid);
        $postParameters['status_url'] = $this->getStatusUrl($oxid);
        $postParameters['cancel_url'] = $this->getCancelUrl();
        $postParameters['language'] = $this->getLang();
        $postParameters['logo_url'] = $skrillSettings['logo_url'];
        $postParameters['prepare_only'] = 1;
        $postParameters['pay_from_email'] = $order->oxorder__oxbillemail->value;
        $postParameters['firstname'] = $order->oxorder__oxbillfname->value;
        $postParameters['lastname'] = $order->oxorder__oxbilllname->value;
        $postParameters['address'] = $order->oxorder__oxbillstreet->value;
        $postParameters['postal_code'] = $order->oxorder__oxbillzip->value;
        $postParameters['city'] = $order->oxorder__oxbillcity->value;
        $postParameters['country'] = SkrillOxCountry::getUserCountryIso2();
        $postParameters['amount'] = $order->oxorder__oxtotalordersum->value;
        $postParameters['currency'] = $order->oxorder__oxcurrency->value;
        $postParameters['detail1_description'] = "Payment to:";
        $postParameters['detail1_text'] = $skrillSettings['recipient_desc'];
        $postParameters['detail2_description'] = "Order Amount:";
        $postParameters['detail2_text'] =
            SkrillCore::setNumberFormat($order->oxorder__oxtotalnetsum->value).' '.$postParameters['currency'];

        $totalShipping = (float) $order->getOrderDeliveryPrice()->getNettoPrice();
        if ($totalShipping > 0) {
            $postParameters['detail3_description'] = "Shipping tax:";
            $postParameters['detail3_text'] =
                SkrillCore::setNumberFormat($totalShipping).' '.$postParameters['currency'];
        }

        $postParameters['merchant_fields'] = 'platform,developer';
        $postParameters['platform'] = '21477246';
        $postParameters['developer'] = 'Payreto';
        if ($this->paymentMethod != 'FLEXIBLE') {
            if ($this->paymentMethod == 'ACC') {
                $postParameters['payment_methods'] = $this->subPaymentMethod;
            } else {
                $postParameters['payment_methods'] = $this->paymentMethod;
            }
        }
        $messageLog = 'Skrill - get post parameters : ' . print_r($postParameters, true);

        return $postParameters;
    }

    private function getLang()
    {
        return oxRegistry::getLang()->getLanguageAbbr();
    }

    private function getSkrillSettings()
    {
        $skrillSettings = array();
        $skrillSettings['merchant_id']      = SkrillConfig::getSetting('skrill_general_merchant_id');
        $skrillSettings['merchant_account'] = SkrillConfig::getSetting('skrill_general_merchant_account_email');
        $skrillSettings['recipient_desc']   = SkrillConfig::getSetting('skrill_general_recipient');
        $skrillSettings['logo_url']         = SkrillConfig::getSetting('skrill_general_logo_url');
        $skrillSettings['api_passwd']       = SkrillConfig::getSetting('skrill_general_api_password');
        $skrillSettings['secret_word']      = SkrillConfig::getSetting('skrill_general_secret_password');

        return $skrillSettings;
    }

    private function getOrderUrl()
    {
        return $this->getViewConfig()->getSelfActionLink() . "&cl=order";
    }

    private function getCancelUrl()
    {
        return $this->getViewConfig()->getSelfActionLink() . "&cl=payment";
    }

    private function getReturnUrl($oxid)
    {
        return $this->getViewConfig()->getSelfActionLink() . "&cl=SkrillOrder&fnc=paymentResponse&oxid=" . $oxid;
    }

    private function getStatusUrl($oxid)
    {
        return $this->getViewConfig()->getSelfActionLink().
            "&cl=SkrillPaymentStatus&oxid=" . $oxid . "&payment_method=" . $this->paymentMethod;
    }

    private function updateOrderTransactionId($transactionId)
    {
        if (!empty(oxRegistry::getSession()->getVariable('skrill_order_status'))) {
            $order = SkrillOxOrder::refreshOrder();

            $order->oxorder__skrill__transaction_id->setValue($transactionId);
            $order->save();
        }
    }
}
