<?php
/**
* 2015 Skrill
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
*
*  @author    Skrill <contact@skrill.com>
*  @copyright 2015 Skrill
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of Skrill
*/

class SkrillConfig
{
    public function __construct()
    {
        $configFile = realpath(dirname(__FILE__) . '/..') . '/config.php';

        include $configFile;
    }

    /**
     * Get payment config by payment id
     *
     * @param  string $paymentId payment method id
     * @return array
     */
    public static function getPaymentConfig($paymentId)
    {
        $paymentMethods = SkrillCore::$paymentMethods;
        $paymentId      = str_replace("skrill_", "", $paymentId);

        $paymentMethod  = $paymentMethods[$paymentId];

        if ($paymentMethod) {
            $paymentConfig['name'] = $paymentMethod['name'];
            $paymentConfig['brand'] = $paymentId;
            if (is_array($paymentMethods['allowedCountries'])) {
                foreach ($paymentMethods['allowedCountries'] as $bankOfCountries) {
                    if (is_array($bankOfCountries)) {
                        foreach (array_keys($bankOfCountries) as $bankName) {
                            $paymentConfig['banks'][] = $bankName;               
                        }
                    }
                }
            }
            $paymentConfig['allowed_countries'] = $paymentMethod['allowedCountries'];
            $paymentConfig['excepted_countries'] = $paymentMethod['exceptedCountries'];
            $paymentConfig['logo'] =
                $paymentMethod['logos'] ? $paymentMethod['logos'] : strtolower($paymentId) . ".png";
        }

        return $paymentConfig;
    }

    /**
     * Get Skrill::$paymentMethods with "skrill_" in front of the payment ID
     * @return array skrill payment methods
     */
    public static function getSkrillPaymentMethods()
    {
        $skrillPaymentMethods = array();
        foreach (SkrillCore::$paymentMethods as $key => $value) {
            $skrillPaymentMethods[ 'skrill_' . $key ] = $value;
        }

        return $skrillPaymentMethods;
    }

    /**
     * Get setting value by variable name that have been set on setting page
     * @param  string $var variable name from oxconfig table
     * @return [string|bool|array]      depend on the variable type
     */
    public static function getSetting($var)
    {
        return oxRegistry::getConfig()->getConfigParam($var);
    }
}
