<?php
/**
 * Skrill Logger
 *
 * The Class for Process Skrill Payment Gateways
 * Copyright (c) Skrill
 *
 * @class   SkrillLogger
 * @package Skrill/Classes
 * @located at /classes
 */
class SkrillLogger
{
    public function __construct()
    {
        $this->config = new SkrillConfig;
    }

    public static function set()
    {
        return new self;
    }

    /**
     * Make info log
     *
     * @param  string $message info message
     * @return null if log level info is not active
     */
    public function info($message)
    {
        if (!$this->isLogLevelActive('INFO')) {
            return;
        }

        $this->message('INFO', $message);
    }

    /**
     * Make error log
     *
     * @param  string $message    error message
     * @param  object $infoObject list of error
     * @return null if log level info is not active
     */
    public function error($message, $infoObject = null)
    {
        if (!$this->isLogLevelActive('ERROR')) {
            return;
        }

        if ($infoObject) {
            $message .= "\n" . json_encode($infoObject) . "\n" . str_repeat('-', 80) . "\n";
        }
        $this->message('ERROR', $message);
    }

    /**
     * Make log
     *
     * @param  string $type    type of log
     * @param  string $message message
     * @return null if log level info is not active
     */
    public function message($type, $message)
    {
        if (!$this->isLogLevelActive($type)) {
            return;
        }

        $logFile = oxRegistry::getConfig()->getLogsDir() . 'skrill'.date("Y-m-d").'.log';
        $date    = date("Y-m-d H:i:s", time());

        $maxSize = (new SkrillConfig)->maximumLogfileSizeInBytes;

        if (!is_file($logFile)) {
            file_put_contents($logFile, "");
        }

        if (filesize($logFile) > $maxSize) {
            file_put_contents($logFile, "$date DELETED LOGFILE (was greater than $maxSize bytes) \n");
        }

        $fLog = fopen($logFile, "a");
        if ($fLog) {
            fwrite($fLog, "$date $type: $message \n");
            fclose($fLog);
        }
    }

    /**
     * Check if spesific log level is active
     *
     * @param  string $level level info/error
     * @return boolean
     */
    protected function isLogLevelActive($level)
    {
        $logLevels = (new SkrillConfig)->logLevels;

        if (in_array('ALL', $logLevels)) {
            return true;
        }
        if (in_array($level, $logLevels)) {
            return true;
        }
        return false;
    }
}
