<?php
/**
 * Skrill OxPayment
 *
 * The Class for Process Skrill Payment Gateways
 * Copyright (c) Skrill
 *
 * @class   SkrillOxPayment
 * @package Skrill/Classes
 * @located at /models
 * @extend  oxpayment
 */
class SkrillOxPayment extends SkrillOxPayment_parent
{

    /**
     * Function checks if loaded payment is valid to current basket
     * Check if payment is using skrill
     *
     * @param array  $aDynvalue    dynamical value (in this case oxidcreditcard and oxiddebitnote are checked only)
     * @param string $sShopId      id of current shop
     * @param oxUser $oUser        the current user
     * @param double $dBasketPrice the current basket price (oBasket->dPrice)
     * @param string $sShipSetId   the current ship set
     *
     * @return bool true if payment is valid
     */
    public function isValidPayment($aDynvalue, $sShopId, $oUser, $dBasketPrice, $sShipSetId)
    {
        $result = parent::isValidPayment($aDynvalue, $sShopId, $oUser, $dBasketPrice, $sShipSetId);

        if (!$result) {
            return $result;
        }

        if (!$this->isSkrillPayment()) {
            return $result;
        }

        switch ($this->getId()) {
            case 'skrill_open_invoice_de':
                return $this->skrillValidateInvoice($aDynvalue);
                break;
            default:
                return $result;
        }
    }

    /**
     * Check if given paymentid is skrill-payment
     *
     * @return bool
     */
    public function isSkrillPayment()
    {
        $paymentConfig = SkrillConfig::getSkrillPaymentMethods();
        return array_key_exists($this->getId(), $paymentConfig);
    }

    /**
     * Validate & format birthdate parameter
     *
     * @param  array $dynvalues
     * @return type
     */
    protected function skrillValidateInvoice($dynvalues)
    {
        if (empty($dynvalues['skrill']['invoice']['birthdate'])) {
            $this->_iPaymentError = 1;
            return false;
        }

        if (!$dynvalues['skrill']['invoice']['agb']) {
            $this->_iPaymentError = 1;
            return false;
        }

        $birthdate = $dynvalues['skrill']['invoice']['birthdate'];

        //convert german format
        if (preg_match('#^([0-9]{1,2})\.([0-9]{1,2})\.([0-9]{4})$#', $birthdate, $matches)) {
            $birthdate = ($matches[3] . '-' . $matches[2] . '-' . $matches[1]);
        }

        if (!preg_match('#^([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})$#', $birthdate, $matches)) {
            $this->_iPaymentError = 1;
            return false;
        }

        //format to yyyy-mm-dd
        $birthdate = explode('-', $birthdate);
        $birthdate = $birthdate[0] . '-' . str_pad($birthdate[1], 2, '0', STR_PAD_LEFT);
        $birthdate .= '-' . str_pad($birthdate[2], 2, '0', STR_PAD_LEFT);

        //store formatted data in session
        $dynvalues['skrill']['invoice']['birthdate'] = $birthdate;
        oxRegistry::getSession()->setVariable('dynvalue', $dynvalues);

        //valid date ?
        if (!strtotime($birthdate)) {
            $this->_iPaymentError = 1;
            return false;
        }

        return true;
    }
}
